Module: GSLng::Special

Extended by:
Special
Included in:
Special
Defined in:
lib/gslng/special.rb

Overview

A group of several different special functions.

=Notes You can use this module simply by acessing its functions. Optionally, you can also extend the Math standard module with these methods by doing: Math.extend(GSLng::Special)

Instance Method Summary collapse

Instance Method Details

#angle_restrict_pos(theta) ⇒ Object

Restrict the given angle to the interval (0,2pi]



18
19
20
# File 'lib/gslng/special.rb', line 18

def angle_restrict_pos(theta)
  GSLng.backend.gsl_sf_angle_restrict_pos(theta)
end

#angle_restrict_symm(theta) ⇒ Object

Restrict the given angle to the interval (-pi,pi]



13
14
15
# File 'lib/gslng/special.rb', line 13

def angle_restrict_symm(theta)
  GSLng.backend.gsl_sf_angle_restrict_symm(theta)
end