Module: GSLng::Special
Overview
A group of several different special functions.
=Notes
You can use this module simply by acessing its functions. Optionally, you can also extend the Math standard module
with these methods by doing:
Math.extend(GSLng::Special)
Instance Method Summary collapse
-
#angle_restrict_pos(theta) ⇒ Object
Restrict the given angle to the interval (0,2pi].
-
#angle_restrict_symm(theta) ⇒ Object
Restrict the given angle to the interval (-pi,pi].